@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
 """Command line tool for managing tmux workspaces and tmuxp configurations.
 
 tmuxp.cli
 ~~~~~~~~~
 
 """
-from __future__ import absolute_import
-
 import importlib
 import logging
 import os
@@ -17,21 +14,20 @@ import click
 import kaptan
 from click.exceptions import FileError
 
+from libtmux import __version__ as libtmux_version
 from libtmux.common import (
+    get_version,
     has_gte_version,
     has_minimum_version,
-    which,
-    get_version,
     tmux_cmd,
+    which,
 )
 from libtmux.exc import TmuxCommandNotFound
 from libtmux.server import Server
 
-from libtmux import __version__ as libtmux_version
-
-from . import config, exc, log, util, __file__ as tmuxp_path
+from . import __file__ as tmuxp_path, config, exc, log, util
 from .__about__ import __version__
-from ._compat import PY3, PYMINOR, string_types
+from ._compat import PY3, PYMINOR
 from .workspacebuilder import WorkspaceBuilder, freeze
 
 logger = logging.getLogger(__name__)
@@ -263,7 +259,7 @@ def scan_config_argument(ctx, param, value, config_dir=None):
         tmuxp_echo(ctx.get_help(), color=ctx.color)
         ctx.exit()
 
-    if isinstance(value, string_types):
+    if isinstance(value, str):
         value = scan_config(value, config_dir=config_dir)
 
     elif isinstance(value, tuple):
@@ -564,7 +560,7 @@ def load_workspace(
         ``tmux -S <socket-path>``
     new_session_name: str, options
         ``tmux new -s <new_session_name>``
-    colors : int, optional
+    colors : str, optional
         '-2'
             Force tmux to support 256 colors
     detached : bool
@@ -664,8 +660,10 @@ def load_workspace(
     sconfig = config.trickle(sconfig)
 
     t = Server(  # create tmux server object
-        socket_name=socket_name, socket_path=socket_path,
-        config_file=tmux_config_file, colors=colors,
+        socket_name=socket_name,
+        socket_path=socket_path,
+        config_file=tmux_config_file,
+        colors=colors,
     )
 
     which('tmux')  # raise exception if tmux not found
@@ -712,8 +710,10 @@ def load_workspace(
             return _setup_plugins(builder)
 
         if 'TMUX' in os.environ:  # tmuxp ran from inside tmux
-            msg = "Already inside TMUX, switch to session? yes/no\n"\
-            "Or (a)ppend windows in the current active session?\n[y/n/a]"
+            msg = (
+                "Already inside TMUX, switch to session? yes/no\n"
+                "Or (a)ppend windows in the current active session?\n[y/n/a]"
+            )
             options = ['y', 'n', 'a']
             choice = click.prompt(msg, value_proc=_validate_choices(options))
 
@@ -749,7 +749,6 @@ def load_workspace(
     return _setup_plugins(builder)
 
 
-
 @click.group(context_settings={'obj': {}})
 @click.version_option(__version__, '-V', '--version', message='%(prog)s %(version)s')
 @click.option(
@@ -1008,12 +1007,11 @@ def command_freeze(session_name, socket_name, socket_path, force):
     '-a',
     'append',
     help='Load configuration, appending windows to the current session',
-    is_flag=True
+    is_flag=True,
 )
 @click.option(
     'colors',
     '-2',
-    type=int,
     flag_value=256,
     default=True,
     help='Force tmux to assume the terminal supports 256 colours.',
@@ -1021,7 +1019,6 @@ def command_freeze(session_name, socket_name, socket_path, force):
 @click.option(
     'colors',
     '-8',
-    type=int,
     flag_value=88,
     help='Like -2, but indicates that the terminal supports 88 colours.',
 )
@@ -1083,7 +1080,7 @@ def command_load(
         tmuxp_echo(ctx.get_help(), color=ctx.color)
         ctx.exit()
 
-    if isinstance(config, string_types):
+    if isinstance(config, str):
         load_workspace(config, **tmux_options)
 
     elif isinstance(config, tuple):
